package com.citictel_cpc.usage;

import com.citictel_cpc.utils.MJDBCUtil;
import com.citictel_cpc.utils.NetworkUtil;
import com.citictel_cpc.utils.Global.PROPERTIES;
import java.net.ConnectException;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;
import javasendmail.HTMLmailObject;

public class CiaFMColocationTrafficSync {

   private static Date runTime;
   private static StringBuffer emailContent = new StringBuffer();
   private static Connection targetConn;
   private static Connection sourceConn;
   private static boolean runSuccess = true;
   private static String emailSuccessTag = "SUCCESS:[MC]";
   private static String emailFailTag = "FAIL:[MC]";
   private static SimpleDateFormat logDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss SSS");
   private static SimpleDateFormat runTimeDateFormat = new SimpleDateFormat("HH:mm:ss SSS");
   private static Map siteInfoMap = new HashMap();
   private static Map trafficMap = new HashMap();
   private static String trafficInsertField = PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.gid_traffic_table_insert_fields");
   private static boolean alwaysSendEmail = PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.always_send_email").equals("true");
   private static String serverIp = NetworkUtil.getServerIp(PROPERTIES.CONFIG.getProperty("service_ip_network_interface_name"));


   public static void main(String[] args) {
      runTime = new Date();

      try {
         initConnection();
         getSiteInfo();
         getTraffic();
         insertTraffic();
      } catch (Exception var5) {
         var5.printStackTrace();
         runFail(var5.getMessage());
      } finally {
         log("total running time: " + (System.currentTimeMillis() - runTime.getTime()) / 1000L + " secs");
         if(!runSuccess || alwaysSendEmail) {
            sendEmail();
         }

      }

   }

   private static void insertTraffic() throws SQLException {
      log("insert traffic to mc traffic table start.");
      String trafficTableExistSql = PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.exist_gid_traffic_table_sql");
      String trafficInsertSql = PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.gid_traffic_table_insert_sql");
      String trafficTablePrefix = PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.gid_traffic_table_prefix");
      String trafficTablesCreateSql = PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.gid_traffic_table_create_sql");
      boolean showInsertSql = PROPERTIES.CONFIG.getProperty("isp_traffic.show_insert_sql").equals("true");
      String executeSql = trafficInsertSql.replaceAll("<<<gid_traffic_table_prefix>>>", trafficTablePrefix);
      StringBuffer existTables = new StringBuffer("|");
      ResultSet rs = targetConn.prepareStatement(trafficTableExistSql).executeQuery();

      while(rs.next()) {
         existTables.append(rs.getString(1)).append("|");
      }

      log("exist traffic tables: " + existTables.toString());

      String executeSqlTemp;
      for(Iterator var9 = trafficMap.entrySet().iterator(); var9.hasNext(); targetConn.prepareStatement(executeSqlTemp).executeUpdate()) {
         Entry entry = (Entry)var9.next();
         if(!existTables.toString().contains(entry.getKey().toString())) {
            targetConn.prepareStatement(trafficTablesCreateSql.replace("<<<gid_traffic_table_prefix>>>", trafficTablePrefix).replace("<<<gid>>>", "" + entry.getKey())).executeUpdate();
            log("create traffic table: " + trafficTablePrefix + "_" + entry.getKey());
         }

         executeSqlTemp = executeSql.replace("<<<gid>>>", "" + entry.getKey()).replace("<<<gid_traffic_table_insert_fields>>>", trafficInsertField).replace("<<<gid_values_sql>>>", ((StringBuffer)entry.getValue()).deleteCharAt(((StringBuffer)entry.getValue()).length() - 1).toString());
         if(showInsertSql) {
            log(executeSqlTemp);
         }
      }

      log("insert traffic to mc traffic table end.");
   }

   private static void getTraffic() throws SQLException {
      log("get traffic start.");
      String trafficSourceSql = PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.traffic_source_sql");
      String[] trafficSourceFields = PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.traffic_source_fields").split(",");
      String[] trafficInsertFields = trafficInsertField.split(",");
      int trafficHourPeriod = Integer.valueOf(PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.traffic_hour_period")).intValue();
      SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
      String fromTime = sdf.format(new Date((new Date()).getTime() - (long)(trafficHourPeriod * 1000 * 60 * 60)));
      String toTime = sdf.format(new Date((new Date()).getTime() + 300000L));
      trafficSourceSql = trafficSourceSql + " where poll_time > \'" + fromTime + "\' and poll_time < \'" + toTime + "\'";
      log("source traffic sql: " + trafficSourceSql);
      ResultSet rs = sourceConn.prepareStatement(trafficSourceSql).executeQuery();
      StringBuffer sb = null;
      log("current server ip: " + serverIp);

      while(rs.next()) {
         HashMap rowMap = new HashMap();
         String[] var13 = trafficSourceFields;
         int var12 = trafficSourceFields.length;

         String field;
         int var11;
         for(var11 = 0; var11 < var12; ++var11) {
            field = var13[var11];
            rowMap.put(field, rs.getObject(field));
         }

         rowMap.put("create_by", serverIp);
         rowMap.put("update_by", serverIp);
         if(siteInfoMap.get(rowMap.get("mc_site_id")) != null) {
            if(trafficMap.get(rowMap.get("gid")) == null) {
               trafficMap.put(rowMap.get("gid"), new StringBuffer());
            }

            sb = ((StringBuffer)trafficMap.get(rowMap.get("gid"))).append("(");
            var13 = trafficInsertFields;
            var12 = trafficInsertFields.length;

            for(var11 = 0; var11 < var12; ++var11) {
               field = var13[var11];
               sb.append("\'" + rowMap.get(field) + "\',");
            }

            sb.deleteCharAt(sb.length() - 1).append("),");
         }
      }

      log("total traffic records: " + trafficMap.size());
      log("get traffic end.");
   }

   private static void getSiteInfo() throws SQLException {
      log("get site info start.");
      String siteInfoSql = PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.site_info_sql");
      String[] siteInfoFields = PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.site_info_source_fields").split(",");
      ResultSet rs = targetConn.prepareStatement(siteInfoSql).executeQuery();

      while(rs.next()) {
         HashMap rowMap = new HashMap();
         String[] var7 = siteInfoFields;
         int var6 = siteInfoFields.length;

         for(int var5 = 0; var5 < var6; ++var5) {
            String field = var7[var5];
            rowMap.put(field, rs.getObject(field));
         }

         siteInfoMap.put(rowMap.get("mc_site_id"), rowMap);
      }

      log("total site info records: " + siteInfoMap.size());
      log("get site info end.");
   }

   private static void initConnection() throws ConnectException {
      log("init connection start.");
      targetConn = MJDBCUtil.getConnection(PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.target_url"), PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.target_username"), PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.target_password"));
      sourceConn = MJDBCUtil.getConnection(PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.source_url"), PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.source_username"), PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.source_password"));
      log("init connection end.");
   }

   private static void log(String content) {
      String logContent = logDateFormat.format(new Date()) + "|" + Thread.currentThread().getName() + "|runTime: " + runTimeDateFormat.format(runTime) + "|--> " + content;
      System.out.println(logContent);
      emailContent.append(logContent + "<br>");
   }

   private static void runFail(String reason) {
      runSuccess = false;
      log(reason);
   }

   private static void sendEmail() {
      String from = PROPERTIES.CONFIG.getProperty("email.from");
      String to = PROPERTIES.CONFIG.getProperty("email.to");
      String cc = PROPERTIES.CONFIG.getProperty("email.cc");
      String reject = PROPERTIES.CONFIG.getProperty("email.reject");
      String subject = PROPERTIES.CONFIG.getProperty("cia_fm_site_traffic.email_subject");
      String host = PROPERTIES.CONFIG.getProperty("email.host");
      if(runSuccess) {
         subject = emailSuccessTag + subject;
      } else {
         subject = emailFailTag + subject;
      }

      HTMLmailObject mail = new HTMLmailObject(from, to, cc, reject, subject, emailContent.toString(), host, "HTML");
      mail.startSend();
   }
}
